pub struct HSFunction<R: RealScalar, const D: DifferentiationLevel> { /* private fields */ }Trait Implementations
Sourceimpl<R: RealScalar, const D: DifferentiationLevel> CostFunction<R> for HSFunction<R, D>
impl<R: RealScalar, const D: DifferentiationLevel> CostFunction<R> for HSFunction<R, D>
Sourceimpl<R: RealScalar, const D: DifferentiationLevel> Function for HSFunction<R, D>
impl<R: RealScalar, const D: DifferentiationLevel> Function for HSFunction<R, D>
fn num_params(&self) -> usize
Sourceimpl<R: RealScalar, const D: DifferentiationLevel> Gradient<R> for HSFunction<R, D>
impl<R: RealScalar, const D: DifferentiationLevel> Gradient<R> for HSFunction<R, D>
Sourcefn gradient_into(&mut self, params: &[R], grad_out: RowMut<'_, R>)
fn gradient_into(&mut self, params: &[R], grad_out: RowMut<'_, R>)
Calculates the gradient for the given parameters.
Sourcefn cost_and_gradient_into(&mut self, params: &[R], grad_out: RowMut<'_, R>) -> R
fn cost_and_gradient_into(&mut self, params: &[R], grad_out: RowMut<'_, R>) -> R
Calculates the cost and gradient for the given parameters.
fn allocate_gradient(&self) -> Row<R>
Sourceimpl<R: RealScalar, const D: DifferentiationLevel> Hessian<R> for HSFunction<R, D>
impl<R: RealScalar, const D: DifferentiationLevel> Hessian<R> for HSFunction<R, D>
Sourcefn hessian_into(&mut self, _params: &[R], _hess_out: MatMut<'_, R>)
fn hessian_into(&mut self, _params: &[R], _hess_out: MatMut<'_, R>)
Calculates the Hessian for the given parameters.
Sourcefn cost_gradient_and_hessian_into(
&mut self,
_params: &[R],
_grad_out: RowMut<'_, R>,
_hess_out: MatMut<'_, R>,
) -> R
fn cost_gradient_and_hessian_into( &mut self, _params: &[R], _grad_out: RowMut<'_, R>, _hess_out: MatMut<'_, R>, ) -> R
Calculates the cost, gradient, and Hessian for the given parameters.
fn allocate_hessian(&self) -> Mat<R>
Sourceimpl<R: RealScalar, const D: DifferentiationLevel> Jacobian<R> for HSFunction<R, D>
impl<R: RealScalar, const D: DifferentiationLevel> Jacobian<R> for HSFunction<R, D>
Sourcefn residuals_and_jacobian_into(
&mut self,
params: &[R],
residuals_out: ColMut<'_, R>,
jacobian_out: MatMut<'_, R>,
)
fn residuals_and_jacobian_into( &mut self, params: &[R], residuals_out: ColMut<'_, R>, jacobian_out: MatMut<'_, R>, )
Calculates the residuals and Jacobian for the given parameters.
Sourcefn jacobian_into(&mut self, params: &[R], jacobian_out: MatMut<'_, R>)
fn jacobian_into(&mut self, params: &[R], jacobian_out: MatMut<'_, R>)
Calculates the Jacobian for the given parameters.
fn allocate_jacobian(&self) -> Mat<R>
Sourceimpl<R: RealScalar, const D: DifferentiationLevel> ResidualFunction<R> for HSFunction<R, D>
impl<R: RealScalar, const D: DifferentiationLevel> ResidualFunction<R> for HSFunction<R, D>
fn num_residuals(&self) -> usize
Sourcefn residuals_into(&mut self, params: &[R], residuals_out: ColMut<'_, R>)
fn residuals_into(&mut self, params: &[R], residuals_out: ColMut<'_, R>)
Calculates the residuals for the given parameters.
fn allocate_residual(&self) -> Col<R>